#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 pretty-simple
version:              4.1.4.0
visibility:           public
id:                   pretty-simple-4.1.4.0-2GrQ58KNVzoI5vfXzXFEU2
key:                  pretty-simple-4.1.4.0-2GrQ58KNVzoI5vfXzXFEU2
license:              BSD-3-Clause
copyright:            2017-2019 Dennis Gosnell
maintainer:           cdep.illabout@gmail.com
author:               Dennis Gosnell
homepage:             https://github.com/cdepillabout/pretty-simple
synopsis:             pretty printer for data types with a '\''Show'\'' instance.
description:
    Please see <https://github.com/cdepillabout/pretty-simple#readme README.md>.

category:             Text
abi:                  a898cc4cee41dc8579146ea85afb406f
exposed:              True
exposed-modules:
    Debug.Pretty.Simple Text.Pretty.Simple Text.Pretty.Simple.Internal
    Text.Pretty.Simple.Internal.Color Text.Pretty.Simple.Internal.Expr
    Text.Pretty.Simple.Internal.ExprParser
    Text.Pretty.Simple.Internal.Printer

import-dirs:          /usr/lib/ghc-9.6.6/site-local/pretty-simple-4.1.4.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/pretty-simple-4.1.4.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/pretty-simple-4.1.4.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-pretty-simple
hs-libraries:         HSpretty-simple-4.1.4.0-2GrQ58KNVzoI5vfXzXFEU2
depends:
    base-4.18.2.1 containers-0.6.7 mtl-2.3.1
    prettyprinter-1.7.2-CIJHFVXNQ7ULgjXbroiIfc
    prettyprinter-ansi-terminal-1.1.4-IGpSNms5NRqAM6mSMhvACs text-2.0.2
    transformers-0.6.1.0

haddock-interfaces:
    /usr/share/doc/haskell-pretty-simple/html/pretty-simple.haddock

haddock-html:         /usr/share/doc/haskell-pretty-simple/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

